==> ozacc-mail-1.0-src.tar.gz: ozacc-mail-1.0/src/java/com/ozacc/mail/spring/XMLMailFactoryBean.java <==
package com.ozacc.mail.spring;

import java.io.File;

import org.springframework.beans.factory.config.AbstractFactoryBean;
import org.springframework.core.io.Resource;

import com.ozacc.mail.Mail;
import com.ozacc.mail.MailBuildException;
import com.ozacc.mail.XMLMailBuilder;

/**
 * Springեǻꤵ줿XMLե뤫Mail󥹥󥹤FactoryBean
 * ǥեȤǤϡsingletonץѥƥfalseꤵޤ
 * <p>
 * locationclassPathfilePathνǡ˥åȤƤץѥƥͤXMLեΥѥȤƻȤޤ
 * 
 * @author Tomohiro Otsuka
 * @version $Id: XMLMailFactoryBean.java,v 1.2 2004/09/11 01:41:59 otsuka Exp $
 */
public class XMLMailFactoryBean extends AbstractFactoryBean {

	private String classPath;

	private String filePath;

	private Resource location;

	private XMLMailBuilder mailBuilder;

	/**
	 * 󥹥ȥ饯
	 */
	public XMLMailFactoryBean() {
		mailBuilder = XMLMailBuilder.getInstance();
		setSingleton(false);
	}

	/**
	 * @see org.springframework.beans.factory.config.AbstractFactoryBean#createInstance()
	 */
	protected Object createInstance() throws Exception {
		if (getLocation() != null && getLocation().getFile() != null) {
			return mailBuilder.buildMail(getLocation().getFile());
		}
		if (getClassPath() != null) {
			return mailBuilder.buildMail(getClassPath());
		}
		if (getFilePath() != null) {
			return mailBuilder.buildMail(new File(getFilePath()));
		}
		throw new MailBuildException("Mail󥹥󥹤˼ԤޤXMLǡΥ󤬻ꤵƤޤ");
	}

	/**
	 * @see org.springframework.beans.factory.FactoryBean#getObjectType()
	 */
	public Class getObjectType() {
		return Mail.class;
	}

	/**
	 * @return Returns the classPath.
	 */
	public String getClassPath() {
		return classPath;
	}

	/**
	 * @param classPath The classPath to set.
	 */
	public void setClassPath(String classPath) {
		this.classPath = classPath;
	}

	/**
	 * @return Returns the filePath.
	 */
	public String getFilePath() {
		return filePath;
	}

	/**
	 * @param filePath The filePath to set.
	 */
	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}

	/**
	 * @return Returns the location.
	 */
	public Resource getLocation() {
		return location;
	}

	/**
	 * @param location The location to set.
	 */
	public void setLocation(Resource location) {
		this.location = location;
	}
}

==> ozacc-mail-1.2-rc6-src.tar.gz: ozacc-mail-1.2-rc6/src/java/com/ozacc/mail/spring/XMLMailFactoryBean.java <==
package com.ozacc.mail.spring;

import java.io.File;

import org.springframework.beans.factory.config.AbstractFactoryBean;
import org.springframework.core.io.Resource;

import com.ozacc.mail.Mail;
import com.ozacc.mail.MailBuildException;
import com.ozacc.mail.MailBuilder;
import com.ozacc.mail.impl.XMLMailBuilderImpl;

/**
 * Springեǻꤵ줿XMLե뤫Mail󥹥󥹤FactoryBean
 * ǥեȤǤϡsingletonץѥƥfalseꤵޤ
 * <p>
 * locationclassPathfilePathνǡ˥åȤƤץѥƥͤXMLեΥѥȤƻȤޤ
 * 
 * @see com.ozacc.mail.impl.XMLMailBuilderImpl
 * 
 * @since 1.0
 * @author Tomohiro Otsuka
 * @version $Id: XMLMailFactoryBean.java,v 1.4 2004/09/13 19:48:16 otsuka Exp $
 */
public class XMLMailFactoryBean extends AbstractFactoryBean {

	private String classPath;

	private String filePath;

	private Resource location;

	private MailBuilder mailBuilder;

	/**
	 * 󥹥ȥ饯
	 */
	public XMLMailFactoryBean() {
		setSingleton(false);
	}

	/**
	 * @see org.springframework.beans.factory.config.AbstractFactoryBean#createInstance()
	 */
	protected Object createInstance() throws Exception {
		if (mailBuilder == null) {
			init();
		}

		if (getLocation() != null && getLocation().getFile() != null) {
			return mailBuilder.buildMail(getLocation().getFile());
		}
		if (getClassPath() != null) {
			return mailBuilder.buildMail(getClassPath());
		}
		if (getFilePath() != null) {
			return mailBuilder.buildMail(new File(getFilePath()));
		}
		throw new MailBuildException("Mail󥹥󥹤˼ԤޤXMLǡΥ󤬻ꤵƤޤ");
	}

	/**
	 * mailBuilder󥹥󥹤ޤ
	 */
	private void init() {
		mailBuilder = new XMLMailBuilderImpl();
	}

	/**
	 * @see org.springframework.beans.factory.FactoryBean#getObjectType()
	 */
	public Class getObjectType() {
		return Mail.class;
	}

	/**
	 * <code>MailBuilder</code>󥿡եμ饹Υ󥹥󥹤򥻥åȤޤ
	 * ǥեȤǤϡ<code>XMLMailBuilderImpl</code>Ѥޤ
	 * <p>
	 * ǥåȤʤϡ<code>XMLMailFactoryBean</code>ҤȤĤդ
	 * <code>XMLMailBuilderImpl</code>󥹥󥹰Ĥݻޤ
	 * 󥰥ȥ<code>MailBuilder</code>󥹥󥹤򥻥åȤ뤳Ȥ侩ޤ
	 * 
	 * @param mailBuilder MailBuilder󥹥
	 */
	public void setMailBuilder(MailBuilder mailBuilder) {
		this.mailBuilder = mailBuilder;
	}

	/**
	 * @return Returns the classPath.
	 */
	public String getClassPath() {
		return classPath;
	}

	/**
	 * @param classPath The classPath to set.
	 */
	public void setClassPath(String classPath) {
		this.classPath = classPath;
	}

	/**
	 * @return Returns the filePath.
	 */
	public String getFilePath() {
		return filePath;
	}

	/**
	 * @param filePath The filePath to set.
	 */
	public void setFilePath(String filePath) {
		this.filePath = filePath;
	}

	/**
	 * @return Returns the location.
	 */
	public Resource getLocation() {
		return location;
	}

	/**
	 * @param location The location to set.
	 */
	public void setLocation(Resource location) {
		this.location = location;
	}
}
